@@ -3,7 +3,7 @@ package Zleep;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use base 'Import::Export';
 
 our %EX = (
@@ -28,7 +28,7 @@ Zleep - zleep
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -79,10 +79,6 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Zleep>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Zleep>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/Zleep>
@@ -93,7 +89,7 @@ L<https://metacpan.org/release/Zleep>
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2024 by LNATION.
+This software is Copyright (c) 2024->2025 by LNATION.
 
 This is free software, licensed under:
 
